abacusai.feature_group_refresh_export_config — AbacusAI documentation

# `abacusai.feature_group_refresh_export_config`

## Module Contents

### Classes

`FeatureGroupRefreshExportConfig` | param client: An authenticated API Client instance

class abacusai.feature_group_refresh_export_config.FeatureGroupRefreshExportConfig(client, connectorType=None, location=None, exportFileFormat=None, additionalIdColumns=None, databaseFeatureMapping=None, externalConnectionId=None, idColumn=None, objectName=None, writeMode=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - connectorType (str) –

    - location (str) –

    - exportFileFormat (str) –

    - additionalIdColumns (list) –

    - databaseFeatureMapping (dict) –

    - externalConnectionId (str) –

    - idColumn (str) –

    - objectName (str) –

    - writeMode (str) –

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict